@@ -11,23 +11,12 @@ package Pod::Weaver::PluginBundle::RSRCHBOY;
 BEGIN {
   $Pod::Weaver::PluginBundle::RSRCHBOY::AUTHORITY = 'cpan:RSRCHBOY';
 }
-$Pod::Weaver::PluginBundle::RSRCHBOY::VERSION = '0.045';
+$Pod::Weaver::PluginBundle::RSRCHBOY::VERSION = '0.046';
 # ABSTRACT: Document your modules like RSRCHBOY does
 
 use strict;
 use warnings;
 
-# for prereqs
-use Pod::Elemental::Transformer::List                  ( );
-use Pod::Weaver::Plugin::Encoding                      ( );
-use Pod::Weaver::Plugin::StopWords                     ( );
-use Pod::Weaver::Section::SeeAlso                      ( );
-use Pod::Weaver::Section::SourceGitHub                 ( );
-use Pod::Weaver::Section::CollectWithIntro             ( );
-use Pod::Weaver::Section::Contributors                 ( );
-use Pod::Weaver::Section::RSRCHBOY::LazyAttributes     ( );
-use Pod::Weaver::Section::RSRCHBOY::RequiredAttributes ( );
-
 use Pod::Weaver::Config::Assembler;
 
 sub _exp { Pod::Weaver::Config::Assembler->expand_package($_[0]) }
@@ -94,7 +83,7 @@ Pod::Weaver::PluginBundle::RSRCHBOY - Document your modules like RSRCHBOY does
 
 =head1 VERSION
 
-This document describes version 0.045 of Pod::Weaver::PluginBundle::RSRCHBOY - released April 10, 2014 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.046 of Pod::Weaver::PluginBundle::RSRCHBOY - released April 11, 2014 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SYNOPSIS
 
@@ -169,13 +158,13 @@ L<Dist::Zilla::PluginBundle::RSRCHBOY|Dist::Zilla::PluginBundle::RSRCHBOY>
 
 =head1 SOURCE
 
-The development version is on github at L<http://github.com/RsrchBoy/Dist-Zilla-PluginBundle-RSRCHBOY>
-and may be cloned from L<git://github.com/RsrchBoy/Dist-Zilla-PluginBundle-RSRCHBOY.git>
+The development version is on github at L<http://https://github.com/RsrchBoy/dist-zilla-pluginbundle-rsrchboy>
+and may be cloned from L<git://https://github.com/RsrchBoy/dist-zilla-pluginbundle-rsrchboy.git>
 
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/RsrchBoy/Dist-Zilla-PluginBundle-RSRCHBOY/issues
+https://github.com/RsrchBoy/dist-zilla-pluginbundle-rsrchboy/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
